import { defineStore } from "pinia";
import type { serverType } from "@/store/types";
import { store } from "@/store";
import {getServer, updateServer} from "@/api/server";
import {storageLocal} from "@pureadmin/utils";

export const useServerStore = defineStore({
  id: "pure-server",
  state: (): serverType => ({
    id: "",
    ipScope: "",
    listenPort: 0,
    privateKey: "",
    publicKey: "",
    postUpScript: "",
    preDownScript: "",
    postDownScript: ""
  }),
  getters: {
    getServerInfo(state) {
      return state;
    }
  },
  actions: {
    SET_ID(id: string) {
      this.id = id;
    },
    SET_IP_SCOPE(ipScope: string) {
      this.ipScope = ipScope;
    },
    SET_LISTEN_PORT(listenPort: number) {
      this.listenPort = listenPort;
    },
    SET_PRIVATE_KEY(privateKey: string) {
      this.privateKey = privateKey;
    },
    SET_PUBLIC_KEY(publicKey: string) {
      this.publicKey = publicKey;
    },
    SET_POST_UP_SCRIPT(postUpScript: number) {
      this.postUpScript = postUpScript;
    },
    SET_PRE_UP_SCRIPT(preDownScript: number) {
      this.preDownScript = preDownScript;
    },
    SET_POST_DOWN_SCRIPT(postDownScript: number) {
      this.postDownScript = postDownScript;
    },
    async getServerApi() {
      return new Promise<any>((resolve, reject) => {
        getServer()
          .then(data => {
            if (data.code === 200) {
              this.SET_ID(data.data.id);
              this.SET_IP_SCOPE(data.data.ipScope);
              this.SET_LISTEN_PORT(data.data.listenPort);
              this.SET_PRIVATE_KEY(data.data.privateKey);
              this.SET_PUBLIC_KEY(data.data.publicKey);
              this.SET_POST_UP_SCRIPT(data.data.postUpScript);
              this.SET_PRE_UP_SCRIPT(data.data.preDownScript);
              this.SET_POST_DOWN_SCRIPT(data.data.postDownScript);
            }
            storageLocal().setItem("server-info",data.data);
            resolve(data);
          })
          .catch(error => {
            reject(error);
          });
      });
    },
    async updateServerApi(data?: object) {
      return new Promise<any>((resolve, reject) => {
        updateServer(data)
          .then(res => {
            resolve(res);
          })
          .catch(error => {
            reject(error);
          });
      });
    }
  }
});
export function useServerStoreHook() {
  return useServerStore(store);
}
