import { defineStore } from "pinia";
import { store, router, resetRouter, type userType } from "../utils";
import { login, logout } from "@/api/login";
import { setToken, removeToken, setUser, userKey } from "@/utils/auth";
import { getUser } from "@/api/user";
import { storageLocal } from "@pureadmin/utils";

export const useUserStore = defineStore({
  id: "pure-user",
  state: (): userType => ({
    id: storageLocal().getItem<any>(userKey)?.id ?? "",
    name: storageLocal().getItem<any>(userKey)?.name ?? "",
    avatar: storageLocal().getItem<any>(userKey)?.avatar ?? "",
    account: storageLocal().getItem<any>(userKey)?.account ?? "",
    email: storageLocal().getItem<any>(userKey)?.email ?? "",
    isAdmin: storageLocal().getItem<any>(userKey)?.isAdmin ?? 0,
    status: storageLocal().getItem<any>(userKey)?.status ?? 1
  }),
  actions: {
    SET_ID(id: string) {
      this.id = id;
    },
    SET_NAME(name: string) {
      this.name = name;
    },
    SET_AVATAR(avatar: string) {
      this.avatar = avatar;
    },
    SET_ACCOUNT(account: string) {
      this.account = account;
    },
    SET_EMAIL(email: string) {
      this.email = email;
    },
    SET_IS_ADMIN(isAdmin: number) {
      this.isAdmin = isAdmin;
    },
    SET_STATUS(status: number) {
      this.status = status;
    },
    /** 登入 */
    async loginByUsername(data?: any) {
      return new Promise<any>((resolve, reject) => {
        login(data)
          .then(data => {
            if (data.code === 200) {
              setToken(data.data); // 设置token
              getUser().then(res => {
                if (res.code === 200) {
                  setUser(res.data);
                }
              });
            }
            resolve(data);
          })
          .catch(error => {
            reject(error);
          });
      });
    },
    /** 前端登出 */
    logout() {
      return new Promise<any>((resolve, reject) => {
        logout()
          .then(data => {
            if (data.code === 200) {
              removeToken();
              resetRouter();
              router.push("/login");
            }
          })
          .catch(err => {
            reject(err);
          });
      });
    }
  }
});

export function useUserStoreHook() {
  return useUserStore(store);
}
